==> csharp-gentoodotnetinfo-1.1.1.tar.bz2: csharp-gentoodotnetinfo-1.1.1/Source/v1/gentoo-dotnet-info-test/GentooDotnetInfo.Tests.Unit.Info/DotnetRuntimeInfoTest.cs <==
/*
 * This file is part of csharp-gentoodotnetinfo - .NET information tool for Gentoo.
 * Copyright (c) 2023, Maciej Barć <xgqt@riseup.net>
 * Licensed under the GNU GPL v2 License
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * csharp-gentoodotnetinfo is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * csharp-gentoodotnetinfo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with csharp-gentoodotnetinfo.  If not, see <https://www.gnu.org/licenses/>.
 */

using System;
using Xunit;

using Gentoo.DotNet.GentooDotnetInfo.Info;

namespace Gentoo.DotNet.GentooDotnetInfo.Tests.Unit.Info
{

    public class DotnetRuntimeInfoFixture : IDisposable
    {

        public DotnetRuntimeInfo dotnetRuntimeInfo { get; }

        public DotnetRuntimeInfoFixture()
        {
            dotnetRuntimeInfo = new DotnetRuntimeInfo();
        }

        public void Dispose()
        {

        }

    }

    public class DotnetRuntimeInfoTest : IClassFixture<DotnetRuntimeInfoFixture>
    {

        private readonly DotnetRuntimeInfoFixture _fixture;

        public DotnetRuntimeInfoTest(DotnetRuntimeInfoFixture fixture)
        {
            _fixture = fixture;
        }

        [Fact]
        public void RuntimeIdentifier_Passes()
        {
            Exception exception = Record.Exception(() =>
            {
                return _fixture.dotnetRuntimeInfo.RuntimeIdentifier;
            });

            Assert.Null(exception);
        }

        [Fact]
        public void ProcessName_Passes()
        {
            Exception exception = Record.Exception(() =>
            {
                return _fixture.dotnetRuntimeInfo.ProcessName;
            });

            Assert.Null(exception);
        }

        [Fact]
        public void ProcessFileName_Passes()
        {
            Exception exception = Record.Exception(() =>
            {
                return _fixture.dotnetRuntimeInfo.ProcessFileName;
            });

            Assert.Null(exception);
        }

        [Fact]
        public void RuntimeDirectory_Passes()
        {
            Exception exception = Record.Exception(() =>
            {
                return _fixture.dotnetRuntimeInfo.RuntimeDirectory;
            });

            Assert.Null(exception);
        }

    }

}

==> csharp-gentoodotnetinfo-2.0.0.tar.bz2: csharp-gentoodotnetinfo-2.0.0/Source/v1/gentoo-dotnet-info-test/GentooDotnetInfo.Tests.Unit.Info/DotnetRuntimeInfoTest.cs <==
/*
 * This file is part of csharp-gentoodotnetinfo - .NET information tool for Gentoo.
 * Copyright (c) 2023, Maciej Barć <xgqt@riseup.net>
 * Licensed under the GNU GPL v2 License
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * csharp-gentoodotnetinfo is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * csharp-gentoodotnetinfo is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with csharp-gentoodotnetinfo.  If not, see <https://www.gnu.org/licenses/>.
 */

using NUnit.Framework;

using Gentoo.DotNet.GentooDotnetInfo.Info;

namespace Gentoo.DotNet.GentooDotnetInfo.Tests.Unit.Info
{

    [TestFixture]
    public class DotnetRuntimeInfoTest
    {

        private DotnetRuntimeInfo _fixture;

        [SetUp]
        public void SetUp()
        {
            _fixture = new();
        }

        [Test]
        public void RuntimeIdentifier_Passes()
        {
            Assert.That(() => _fixture.RuntimeIdentifier, Throws.Nothing);
        }

        [Test]
        public void ProcessName_Passes()
        {
            Assert.That(() => _fixture.ProcessName, Throws.Nothing);
        }

        [Test]
        public void ProcessFileName_Passes()
        {
            Assert.That(() => _fixture.ProcessFileName, Throws.Nothing);
        }

        [Test]
        public void RuntimeDirectory_Passes()
        {
            Assert.That(() => _fixture.RuntimeDirectory, Throws.Nothing);
        }

    }

}
